`cesium`: Open-Source Platform for Time Series Inference
========================================================

|github| |license|

.. |github| image:: https://img.shields.io/badge/GitHub-cesium--ml%2Fcesium-blue
   :target: https://github.com/cesium-ml/cesium

.. |license| image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://github.com/cesium-ml/cesium/LICENSE.txt


Summary
-------

`cesium` is an open source library that allows users to:
- extract features from raw time series data (`see the feature table <./feature_table.html>`_),
- build machine learning models from these features, and
- generate predictions for new data.

More information and `examples <http://cesium-ml.org/docs/auto_examples/index.html>`_ can be found on our `home page <http://cesium-ml.org>`_.

License
-------
`cesium` uses the `3-clause BSD licence <https://github.com/cesium-ml/cesium/blob/main/LICENSE.txt>`_.

.. toctree::
   :maxdepth: 2

   Installation <install>
   Time-Series Features <feature_table>
   Examples <auto_examples/index>
   API <api/api>

Contributing
------------

cesium is released under the BSD license.  We encourage you to
modify it, reuse it, and contribute changes back for the benefit of
others.  We follow standard open source development practices: changes
are submitted as pull requests and, once they pass the test suite,
reviewed by the team before inclusion.  Please also see
`our contributing guide <./contributing.html>`_.

Acknowledgments
---------------
We thank the Gordon and Betty Moore Foundation for a
`Software SkyPortal grant <https://www.moore .org/grant-detail?grantId=GBMF9122>`_,
which partially covered the cost of the development of this project.


.. image:: https://www.moore.org/content/images/logo-light.png
   :target: https://www.moore.org/grant-detail?grantId=GBMF9122
   :alt: Moore Foundation Logo


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
